@@ -11,6 +11,8 @@
 #' or a model to be used as a denominator. Ignored for \code{BFBayesFactor}.
 #' @inheritParams hdi
 #'
+#' @note There is also a \href{https://easystats.github.io/see/articles/bayestestR.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#'
 #' @details
 #' If the passed models are supported by \pkg{insight} the DV of all models will be tested for equality
 #' (else this is assumed to be true), and the models' terms will be extracted (allowing for follow-up
@@ -134,7 +136,6 @@ bayesfactor_models <- function(..., denominator = 1, verbose = TRUE) {
 #' @export
 bf_models <- bayesfactor_models
 
-#' @importFrom stats BIC
 #' @export
 bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
   # Organize the models and their names
@@ -158,43 +159,39 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
   mforms <- mnames
 
   # supported models
-  supported_models <- all(sapply(mods, insight::is_model_supported))
-  if (supported_models) {
-    # Test that all is good:
-    resps <- lapply(mods, insight::get_response)
+  supported_models <- sapply(mods, insight::is_model_supported)
+  if (all(supported_models)) {
+    temp_forms <- sapply(mods, .find_full_formula)
 
-    if (!any(sapply(resps, is.null))) {
-      if (!all(sapply(resps[-denominator], function(x) identical(x, resps[[denominator]])))) {
-        stop("Models were not computed from the same data.")
-      }
+    has_terms <- sapply(temp_forms, nchar) > 0
 
-      mforms <- sapply(mods, .find_full_formula)
-    } else {
-      supported_models <- FALSE
+    mforms[has_terms] <- temp_forms[has_terms]
+    supported_models[!has_terms] <- FALSE
+  }
+
+  if (!all(supported_models)) {
+    if (verbose) {
+      warning(sprintf(
+        "Unable to extract terms from the following models: \n%s",
+        paste0(mnames[!supported_models], collapse = ", ")
+      ), call. = FALSE)
     }
   }
 
-  if (verbose && !supported_models) {
-    object_names <- match.call(expand.dots = FALSE)$`...`
-    warning(sprintf(
-      "Unable to extract terms / validate that the following models use the same data: \n%s",
-      paste0(mnames[!supported_models], collapse = ", ")
-    ), call. = FALSE)
-  }
-
   # Get BF
-  mBIC <- sapply(mods, BIC)
-  mBFs <- (mBIC - mBIC[denominator]) / (-2)
+  names(mods) <- mforms
+  mBIC <- .BIC_list(mods)
+  mBFs <- exp((mBIC - mBIC[denominator]) / (-2))
 
   res <- data.frame(
     Model = mforms,
-    BF = exp(mBFs),
+    BF = mBFs,
     stringsAsFactors = FALSE
   )
 
   attr(res, "denominator") <- denominator
   attr(res, "BF_method") <- "BIC approximation"
-  attr(res, "unsupported_models") <- !supported_models
+  attr(res, "unsupported_models") <- !all(supported_models)
   class(res) <- c("bayesfactor_models", "see_bayesfactor_models", class(res))
 
   res
@@ -207,7 +204,7 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
     stop("Package 'bridgesampling' required for this function to work. Please install it by running `install.packages('bridgesampling')`.")
   }
 
-  # Orgenize the models
+  # Organize the models
   mods <- list(...)
 
   # Warn
@@ -237,7 +234,9 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
 
   # Test that all is good:
   resps <- lapply(mods, insight::get_response)
-  if (!all(sapply(resps[-denominator], function(x) identical(x, resps[[denominator]])))) {
+  from_same_data_as_den <- sapply(resps[-denominator],
+                                  identical, y = resps[[denominator]])
+  if (!all(from_same_data_as_den)) {
     stop("Models were not computed from the same data.")
   }
 
@@ -249,7 +248,8 @@ bayesfactor_models.default <- function(..., denominator = 1, verbose = TRUE) {
     bridgesampling::bridge_sampler(x, silent = TRUE)
   })
   mBFs <- sapply(mML, function(x) {
-    bridgesampling::bf(x, mML[[denominator]], log = TRUE)[["bf"]]
+    bf <- bridgesampling::bf(x, mML[[denominator]], log = TRUE)
+    bf[["bf"]]
   })
 
   # Get formula
@@ -297,7 +297,12 @@ bayesfactor_models.BFBayesFactor <- function(..., verbose = TRUE) {
   }
   mBFs <- c(0, BayesFactor::extractBF(models, TRUE, TRUE))
   mforms <- sapply(c(models@denominator, models@numerator), function(x) x@shortName)
-  mforms[mforms == "Intercept only"] <- "1"
+
+  if (!"BFlinearModel" %in% class(models@denominator)) {
+    mforms <- .clean_non_linBF_mods(mforms)
+  } else {
+    mforms[mforms == "Intercept only"] <- "1"
+  }
 
   res <- data.frame(
     Model = unname(mforms),
@@ -336,3 +341,70 @@ bayesfactor_models.BFBayesFactor <- function(..., verbose = TRUE) {
   }
   paste(c(conditional, random), collapse = " + ")
 }
+
+#' @keywords internal
+#' @importFrom stats BIC
+.BIC_list <- function(x){
+  sapply(x, function(m) {
+    tryCatch({
+      bic <- stats::BIC(m, x[[1]])
+      bic$BIC[1]
+    }, warning = function(w) {
+      stop(conditionMessage(w), call. = FALSE)
+    })
+  })
+}
+
+#' @keywords internal
+.clean_non_linBF_mods <- function(m_names){
+  tryCatch({
+    m_txt <- character(length = length(m_names))
+
+    ## Detect types ##
+    is_null <- grepl("^Null", m_names)
+    is_rho <- grepl("rho", m_names)
+    is_mu <- grepl("mu", m_names)
+    is_d <- grepl("d", m_names)
+    is_p <- grepl("p", m_names)
+    is_range <- grepl("<", m_names)
+
+    ## Range Alts ##
+    m_txt[!is_null & is_range] <-
+      sub("^[^\\s]*\\s[^\\s]*\\s", "", m_names[!is_null & is_range])
+
+    ## Null models + Not nulls ##
+    if (any(is_d & is_p)) {
+      is_null <- !grepl("^Non", m_names)
+      temp <- m_names[is_null][1]
+      mi <- gregexpr("\\(.*\\)", temp)
+      aa <- unlist(regmatches(temp, m = mi))
+
+      m_txt[is_null] <- sub("a=","a = ",aa)
+      m_txt[!is_null & !is_range] <- sub("a=","a != ",aa)
+    } else if (any(is_rho)) {
+      m_txt[is_null] <- "rho = 0"
+      m_txt[!is_null & !is_range] <- "rho != 0"
+      m_txt <- sub("<rho<", " < rho < ", m_txt)
+    } else if (any(is_d | is_mu)) {
+      m_txt[is_null] <- "d = 0"
+      m_txt[!is_null & !is_range] <- "d != 0"
+      m_txt <- sub("<d<", " < d < ", m_txt)
+    } else if (any(is_p)) {
+      temp <- m_names[is_null][1]
+      mi <- gregexpr("[0-9|\\.]+", temp)
+      pp <- unlist(regmatches(temp, m = mi))
+
+      m_txt[is_null] <- paste0("p = ", pp)
+      m_txt[!is_null & !is_range] <- paste0("p != ", pp)
+      m_txt <- sub("<p<", " < p < ", m_txt)
+    } else {
+      stop("!")
+    }
+
+    ## wrap with () for readability ##
+    is_wrapped <- grepl("\\(", m_txt)
+    m_txt[!is_wrapped] <- paste0("(", m_txt[!is_wrapped], ")")
+
+    return(m_txt)
+  }, error = function(e) return(m_names))
+}
