@@ -1,6 +1,6 @@
 #' @importFrom insight print_color
 #' @export
-print.bayesfactor_models <- function(x, digits = 2, log = FALSE, ...) {
+print.bayesfactor_models <- function(x, digits = 3, log = FALSE, ...) {
   BFE <- x
   denominator <- attr(BFE, "denominator")
   grid.type <- attr(BFE, "BF_method")
@@ -9,7 +9,7 @@ print.bayesfactor_models <- function(x, digits = 2, log = FALSE, ...) {
   if (log) {
     BFE$BF <- log(BFE$BF)
   }
-  BFE$BF <- .format_big_small(BFE$BF, digits = digits)
+  BFE$BF <- insight::format_value(BFE$BF, digits = digits, missing = "NA")
 
   # indicate null-model
   BFE$Model[BFE$Model == "1"] <- "(Intercept only)"
@@ -18,7 +18,7 @@ print.bayesfactor_models <- function(x, digits = 2, log = FALSE, ...) {
   denM <- .trim(BFE$Model[denominator])
   BFE <- BFE[-denominator, ]
   BFE$Model <- format(BFE$Model)
-  colnames(BFE) <- c(format(" Model", width = max(nchar(BFE$Model))), "Bayes Factor")
+  colnames(BFE) <- c(format(" Model", width = max(nchar(BFE$Model))), "BF")
 
   insight::print_color("# Bayes Factors for Model Comparison\n\n", "blue")
 
